(* $Id: pax_clipboard.ml 799 2008-06-03 15:13:33Z gerd $ 
 * ----------------------------------------------------------------------
 * Copyright 2003 by Gerd Stolpmann.
 *
 * This file is part of godi-tools.
 *
 * godi-tools is free software; you can redistribute it and/or modify it
 * under the conditions in the file LICENSE.
 *
 * godi-tools is distributed WITHOUT ANY WARRANTY, as detailed in the
 * file LICENSE.
 *)

(* Clipboards are used for pax copy mode *)

open Pax_types

class clipboard prefix_opt =
object(clipboad)

  val mutable saved_metadata = None


  method archive_type = "clipboard"

  method create_archive() =
    ( object(writer)
	method put_data _ = assert false

	method put_metadata_only m =
	  saved_metadata <- Some m

	method close() = ()

      end : archive_wr
    )

  method read_archive() =
    Some 
      ( object(reader)
	  method get_metadata = 
	    match saved_metadata with
	      | None -> assert false
	      | Some m -> m

	  method get_data() =
	    let m = reader#get_metadata in
	    let name = m#name in
	    let local_name =
	      match prefix_opt with
		| None -> Godi_file.filename name
		| Some p -> Godi_file.concat p (Godi_file.filename name) in
	    let file_id = 
	      try Godi_file.file_id local_name
	      with _ -> Godi_file.file_id ~symlink:true local_name
	    in
	    `File(local_name, file_id)

	  method next() =
	    None
  	end : archive_rd
      )
end
